@@ -1,3 +1,8 @@
+"""
+
+Author: Martin Benes
+Affiliation: Universitaet Innsbruck
+"""
 
 import sys
 import unittest
@@ -11,17 +16,17 @@ if __name__ == "__main__":
     logging.info(f"{jpeglib.__path__=}")
 
 # === unit tests ===
-from test_cstruct import TestCStruct  # noqa: F401,E402
+from test_cenum import TestCEnum  # noqa: F401,E402
 from test_dct import TestDCT  # noqa: F401,E402
 from test_interface import TestInterface  # noqa: F401,E402
+from test_marker import TestMarker  # noqa: F401,E402
 from test_notation import TestNotation  # noqa: F401,E402
 from test_performance import TestPerformance  # noqa: F401,E402
+from test_progressive import TestProgressive  # noqa: F401,E402
 from test_spatial import TestSpatial  # noqa: F401,E402
 from test_version import TestVersion  # noqa: F401,E402
 
 # from test_flags import TestFlags  # noqa: F401,E402
-# from test_marker import TestMarker  # noqa: F401,E402
-# from test_progressive import TestProgressive  # noqa: F401,E402
 # ==================
 
 # run unittests
